spoon.transports.transports

Package spoon :: Package transports :: Module transports |
[hide private]
[frames] | no frames]

# Module transports

source code

Classes | [hide private]
`` | SpoonRPCHello This object is sent as a very simple form of initial negotiation.
`` | LinkMessage Link message is the wrapper which will contain messages sent between two directly connected nodes.
`` | TransportException
`` | TransportHub Where all of your transports connect to form your glorious new node.

Functions | [hide private]
`` | encode_linkmessage(fd, obj)
`` | decode_linkmessage(fd, tag)

Function Details | [hide private]

### encode_linkmessage(fd, obj) | source code
None Decorators: `@ber.encoder(LinkMessage)`

### decode_linkmessage(fd, tag) | source code
None Decorators: `@ber.decoder(__SPOONLINKMSG_TAG__)`